from unittest import TestCase
import unittest.mock as mock
from src.utils import *
import random
import os.path as osp
import os
import json
import numpy as np


class TestUtils(TestCase):
    def setUp(self):
        self.current_dir = os.getcwd()

    def tearDown(self):
        for dir in os.listdir(self.current_dir):
            if (osp.isdir(dir)):
                os.rmdir(dir)

    def test_digits_in_string(self):
        txt = 'video10'
        digit = 10
        self.assertEqual(digits_in_string(txt), int(digit))
        self.assertEqual(type(digits_in_string(txt)), int)

    def test_make_directory(self):
        dir = os.path.join(self.current_dir, 'test_dir' + str(random.randint(1, 10000)))
        print(dir)
        dir = make_directory(dir)
        self.assertTrue(osp.exists(dir), False)

    def test_open_json_file(self):
        # test valid JSON
        read_data = json.dumps({'a': 1, 'b': 2, 'c': 3})
        mock_open = mock.mock_open(read_data=read_data)
        with mock.patch('builtins.open', mock_open):
            result = read_json('file')
        self.assertEqual({'a': 1, 'b': 2, 'c': 3}, result)
        # test invalid JSON
        read_data = ''
        mock_open = mock.mock_open(read_data=read_data)
        with mock.patch("builtins.open", mock_open):
            with self.assertRaises(ValueError) as context:
                read_json('file')
            self.assertEqual(
                'file is not valid', str(context.exception))
        # test file does not exist
        with self.assertRaises(IOError) as context:
            read_json('null')
        self.assertEqual(
            'null does not exist.', str(context.exception))

    def test_drop_file_extension(self):
        file = 'test.mat'
        self.assertEqual('test', drop_file_extension(file))
        self.assertEqual('', drop_file_extension(''))
        with self.assertRaises(ValueError):
            drop_file_extension(None)

    def test_make_sorted_sample(self):
        arr = np.arange(4)
        n_samples = 2
        sample = make_sorted_sample(arr, n_samples)
        self.assertTrue(len(sample), n_samples)
        self.assertTrue(sample[1] > sample[0])

    def test_sample_from_video_with_gt(self):
        fps = 30
        duration = 20
        n_frames=int(fps*duration)
        user_scores = np.random.randint(low=0, high=2, size=n_frames)
        user_scores=np.expand_dims(user_scores, axis=1)
        video_frames = list(np.random.randn(n_frames))
        sampled_frames, sampled_gt = sample_from_video_with_gt(video_frames, user_scores, duration, fps, n_samples=2)
        self.assertEquals(len(sampled_frames), len(sampled_gt))

    def test_has_string(self):
        self.assertTrue(has_string('Frame123','frame'))
        self.assertTrue(has_string('frame123', 'Frame'))
        self.assertFalse(has_string('', 'frame'))
        with self.assertRaises(ValueError):
            has_string(None,'string')